==> themetweaker.themeswitcher-0.8.7b1.tar.gz: themetweaker.themeswitcher-0.8.7b1/setup.py <==
from setuptools import setup, find_packages
import os

setup(name='themetweaker.themeswitcher',
      version='0.8.7b1',
      author='WebLion Group, Penn State University',
      author_email='support@weblion.psu.edu',
      description="A product for switching themes in Plone.",
      long_description=open('README.txt').read() + "\n" +
                       open(os.path.join("docs", "HISTORY.txt")).read(),
      # Get more strings from http://www.python.org/pypi?%3Aaction=list_classifiers
      classifiers=[
        "Framework :: Plone",
        "Framework :: Zope2",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2.4",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Intended Audience :: Developers",
        "Development Status :: 3 - Alpha",
        ],
      keywords='themeswitcher themetweaker theme switcher weblion',
      url='https://weblion.psu.edu/trac/weblion/wiki/ThemeSwitcher',
      license='GPL',
      packages=find_packages('src'),
      package_dir = {'': 'src'},
      namespace_packages=['themetweaker',],
      extras_require = dict(test=['zope.app.testing',
                                  'zope.testing',
                                  'zope.traversing',
                                  ]),
      install_requires=[
          'setuptools',
          # 'plone>=3.2',
          'plone.browserlayer==1.0.0',
          'z3c.unconfigure==1.0.1',
          'sd.common' # subversion?
          # -*- Extra requirements: -*-
      ],
      entry_points="""
      # -*- Entry points: -*-
      """,
      include_package_data=True,
      zip_safe=False,
      )

==> themetweaker.themeswitcher-0.9b1.tar.gz: themetweaker.themeswitcher-0.9b1/setup.py <==
from setuptools import setup, find_packages
import os

setup(name='themetweaker.themeswitcher',
      version='0.9b1',
      author='Six Feet Up, Inc. <info at sixfeetup com> | WebLion Group, Penn State University',
      author_email='support@weblion.psu.edu',
      description="A product for switching themes in Plone.",
      long_description=open('README.txt').read() + "\n\n" +
                       open(os.path.join("docs", "INSTALL.txt")).read() + "\n\n" +
                       open(os.path.join("docs", "HISTORY.txt")).read(),
      # Get more strings from http://www.python.org/pypi?%3Aaction=list_classifiers
      classifiers=[
        "Framework :: Plone",
        "Framework :: Zope2",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2.4",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Intended Audience :: Developers",
        "Development Status :: 4 - Beta",
        ],
      keywords='themeswitcher themetweaker theme switcher weblion',
      url='https://weblion.psu.edu/trac/weblion/wiki/ThemeSwitcher',
      license='GPL',
      packages=find_packages('src'),
      package_dir = {'': 'src'},
      namespace_packages=['themetweaker',],
      extras_require = dict(test=['zope.app.testing',
                                  'zope.testing',
                                  'zope.traversing',
                                  ]),
      install_requires=[
          'setuptools',
          'sd.common', # TODO get trollfot to release this package
      ],
      dependency_links=["http://tracker.trollfot.org/svn/projects/sd.common/trunk/#egg=sd.common",],
      entry_points="""
      # -*- Entry points: -*-
      """,
      include_package_data=True,
      zip_safe=False,
      )
